########################################################################################################
#### Title: Adjoint and direct characteristic equations for two-dimensional compressible Euler flows
#### Authors: Kevin Ancourt, Jacques Peter, Oliver Atinault
########################################################################################################

import numpy as np
from determinants_dim_2_7 import *
import sympy as sp 


gam = 1.4
gam1 = gam - 1.
#-----------------------
#
ro  = 0.55
p   = 1.12
rop = ro*p 
c  = np.sqrt(gam*p/ro)
M  = 1.3
nx = np.sqrt(0.5)                          # (nx,ny) unit vector
ny = np.sqrt(1.-nx**2)              # + or -  
#
#------------------------
#
u  = M*nx*c
v  = M*ny*c
Ec = 0.5*(u**2+v**2)
H  = Ec + gam/gam1*p/ro 
E  = p/ro/gam1 + Ec
#
#--------------------------------
#
phi = np.arctan(ny/nx)
bet = np.arcsin(1./M)
#
dx =  2.*np.cos(phi+bet)    # C+ characteristics
dy =  2.*np.sin(phi+bet)
t  = dy/dx
kappa  = u*t-v # w = kappa
#
#----------------------------------------------------------------------
#
#-----------------------------------------------------------------------

a1p1 =  0. #a1p1 = a1p1 /a11
a1p2 = gam1 * Ec - u**2
a1p3 =  -u*v
a1p4 = (gam1*Ec-H)*u

a2p1 = 1.
a2p2 = (3-gam)*u
a2p3 = v
a2p4 = (H-gam1*u**2)

a3p1 = 0.
a3p2 = -gam1 *v
a3p3 = u
a3p4 = -gam1 * u * v 

a4p1 = 0.
a4p2 = gam1
a4p3 = 0.
a4p4 = gam*u

#-----------------------------------------------

b1p1 = 0.
b1p2 =  -u*v
b1p3 = gam1*Ec-v**2
b1p4 =(gam1*Ec-H)*v

b2p1 =0. 
b2p2 = v
b2p3 = -gam1*u
b2p4 = -gam1*u*v

b3p1 = 1.
b3p2 =  u
b3p3 = (3-gam)*v
b3p4 = H-gam1 * v**2

b4p1 = 0.
b4p2 = 0.
b4p3 = gam1
b4p4 = gam*v

#-----------------------------------------------------
b1pta1 = 0. 
b1pta2 = u*kappa - t*gam1*Ec #-u*v -t * (gam1*Ec-u**2)
b1pta3 =gam1 * Ec + v* kappa #  gam1 *Ec - v**2 + t*u*v
b1pta4 = -kappa * (gam1*Ec - H) #(gam1*Ec -H)*v -u*t*(gam1*Ec -H)


b2pta1 = -t 
b2pta2 =  v - t*u*(3-gam)
b2pta3 = -gam1*u - t*v 
b2pta4 = gam1*u*kappa -t*H

b3pta1 = 1.
b3pta2 = u+t*gam1*v
b3pta3 = (3-gam)*v - t*u
b3pta4 =  H + gam1*v*kappa

b4pta1 = 0.
b4pta2 = -t*gam1
b4pta3 = gam1 
b4pta4 = -gam*kappa


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprho/dpx   -- ")
print("****************************************************************")

 
K11x_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K11x_d4 = dx**3 * det4( b1p1,b2pta1,b3pta1,b4pta1, b1p2,b2pta2,b3pta2,b4pta2,\
                  b1p3,b2pta3,b3pta3,b4pta3, b1p4,b2pta4,b3pta4,b4pta4)
    

K11x_d3 = dx**3 *t * det3(-u*v,u+t*gam1*v , -t*gam1, \
                          gam1*Ec -v**2 , (3-gam)*v - t*u , gam1 , \
                          (gam1*Ec-H)*v, H+gam1*v*kappa ,-gam*kappa )    + dx**3 * det3(-u*v , v- t*u*(3-gam), -t*gam1 , gam1*Ec-v**2, -gam1*u -t*v , gam1,\
                                                                                (gam1*Ec-H)*v , gam1*u*kappa -t*H , - gam*kappa)    
K11x_c = -dx **3*kappa*(v*kappa**2 -H*gam1*v - H*gam1*t**2*v + gam1*Ec*(u*t+v)+ gam1*t**2*2*Ec*v) 

print(" ")
print(" K11x  det7     ",K11x_d7)
print(" K11x  det4     ",K11x_d4)
print(" K11x  det3     ",K11x_d3)
print("----")
print(" K11x  calc     ",K11x_c)
print("-----------------------------------------")



K21x_d7 =  det7(0.,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,0.,dy,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K21x_d4  = -dx**2*dy*det4(a2p1,b2p1,b3pta1,b4pta1,a2p2,b2p2,b3pta2,b4pta2,\
                       a2p3,b2p3,b3pta3,b4pta3,a2p4,b2p4,b3pta4,b4pta4)

K21x_c = -dx**3 *t* kappa * (gam*kappa*v +2*Ec * (gam-1))


print(" ")
print(" K21x  det7     ",K21x_d7)
print(" K21x  det4     ",K21x_d4)
print(" K21x  calc     ", K21x_c)

print("-----------------------------------------")



K31x_d7 =  det7(0.,0.,0.,dy,0.,0.,0.,\
             dx,0.,0.,0.,dy,0.,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K31x_d4  = dx**2*dy*det4(a3p1,b2pta1,b3p1,b4pta1,a3p2,b2pta2,b3p2,b4pta2,\
                      a3p3,b2pta3,b3p3,b4pta3,a3p4,b2pta4,b3p4,b4pta4)

K31x_c = dx**3 *t*kappa*(-2*Ec*t + gam*v*(t*v+u))
  
print(" ")
print(" K31x   det7     ",K31x_d7)
print(" K31x   det4     ",K31x_d4)
print(" K31x   calc     ", K31x_c)
print("-----------------------------------------")


K41x_d7 =  det7(0.,0.,0.,dy,0.,0.,0.,\
             dx,0.,0.,0.,dy,0.,0.,\
             0.,dx,0.,0.,0.,dy,0.,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K41x_d4 = -dx**2*dy*det4(a4p1,b2pta1,b3pta1,b4p1,a4p2,b2pta2,b3pta2,b4p2,\
                      a4p3,b2pta3,b3pta3,b4p3,a4p4,b2pta4,b3pta4,b4p4)
    
K41x_c = dx**3 *t * kappa *gam1 *(t*v+u)

print(" ")
print(" K41x    det7    ",K41x_d7)
print(" K41x    det4    ",K41x_d4)
print(" K41x    calc    ", K41x_c)
print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprhou/dpx  -- ")
print("****************************************************************")
    
K12x_d7 =  det7(0.,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)   
    
K12x_d4 = dx**2*dy*det4(a1p1, b1p1,b3pta1,b4pta1,a1p2,  b1p2,b3pta2,b4pta2,\
                        a1p3,b1p3,b3pta3,b4pta3,  a1p4,  b1p4,b3pta4,b4pta4)
        
K12x_c = dx**3*gam1*t*Ec*kappa*( -H*gam1 + (gam+1)*Ec)

print(" ")
print(" K12x det7       ",K12x_d7)
print(" K12x det4       ",K12x_d4)
print(" K12x calc       ",K12x_c)

print("-----------------------------------------")


    
K22x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)    

K22x_d4 = dx**3*det4( b1pta1, b2p1,b3pta1,b4pta1,  b1pta2, b2p2,b3pta2,b4pta2,\
                     b1pta3, b2p3,b3pta3,b4pta3,  b1pta4, b2p4,b3pta4,b4pta4)
    

K22x_c = dx**3 * kappa * (gam1**2*t*u*Ec + gam1*Ec*kappa + v**2*kappa + H*gam1*v -H*gam1**2*t*u+gam1*t*u*Ec)
print(" K22x   det7    ",K22x_d7)
print(" K22x   det4    ",K22x_d4)
print(" K22x   calc    ", K22x_c )
print("------------------------------------------")

K32x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,0.,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)   

K32x_d4 = dx**2*dy*det4(a3p1,  b1pta1,b3p1,b4pta1,  a3p2,  b1pta2 ,b3p2,b4pta2,\
                        a3p3,  b1pta3,b3p3,b4pta3,  a3p4,  b1pta4,b3p4,b4pta4)

K32x_c=dx**3*t*kappa*(H*gam1**2*v - gam1*v*Ec - gam1**2*v*Ec + u**2*kappa + gam1*kappa*Ec - H*gam1*t*u)


print(" K32x   det7    ",K32x_d7)
print(" K32x   det4    ",K32x_d4)
print(" K32x   calc    ", K32x_c )
print("----------------------------------------")


K42x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)   
      
    
K42x_d4 = -dx**2*dy*det4(a4p1,   b1pta1,b3pta1,b4pta1,  a4p2,   b1pta2,b3pta2,b4pta2,\
                         a4p3,  b1pta3,b3pta3,b4pta3,  a4p4,  b1pta4,b3pta4,b4pta4)
    

K42x_c =  dx**3*gam1*t*kappa*( H*gam1 - (gam+1)*Ec)

print(" K42x   det7     ",K42x_d7)
print(" K42x   det4     ",K42x_d4)
print(" K42x   calc     ", K42x_c )
print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded dprhov/dpx   --- ")
print("****************************************************************")


K13x_d7 =  det7(0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,0.,0.,0.,dy,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)   
    
K13x_d4 = dx**2*dy*det4(a1p1, b1p1,b2pta1,b4pta1,a1p2,  b1p2,b2pta2,b4pta2,\
                      a1p3,b1p3,b2pta3,b4pta3,  a1p4,  b1p4,b2pta4,b4pta4)

K13x_c = dx**3*gam1*t*Ec*kappa*t*(H*gam1 - (gam+1)*Ec)

print(" K13x    det7     ",K13x_d7)
print(" K13x    det4     ",K13x_d4)
print(" K13x    calc     ", K13x_c )
print("-----------------------------------------")

K23x_d7   =  det7(dx,0.,0.,dy,0.,0.,0.,\
                  0.,0.,0.,0.,0.,dy,0.,\
                  0.,0.,dx,0.,0.,0.,dy,\
                  a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                  a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                  a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                  a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)    

K23x_d4 = -dx**2*dy*det4(a2p1, b1pta1,b2p1,b4pta1,a2p2, b1pta2,b2p2,b4pta2,\
                         a2p3,b1pta3,b2p3,b4pta3,a2p4, b1pta4,b2p4,b4pta4)
    

K23x_c=dx **3*t*kappa*(-v**2*kappa - gam1*kappa*Ec - gam1**2*t*u *Ec - H*gam1*v + H*gam1**2*t*u -gam1*t*u*Ec )
print("----")
print(" K23x   det7      ",K23x_d7)
print(" K23x   det4      ",K23x_d4)
print(" K23x   calc      ", K23x_c)

print("-----------------------------------------")
K33x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)    
 

        
K33x_d4 =  dx**3*det4(  b1pta1, b2pta1,b3p1,b4pta1,  b1pta2, b2pta2,b3p2,b4pta2,\
                       b1pta3, b2pta3,b3p3,b4pta3, b1pta4, b2pta4,b3p4,b4pta4)
    
K33x_c = dx**3*kappa*(-v**3 + 3*t*u*v**2 -H*gam1*kappa - 2*t**2*u**2*v+gam1**2*t**2*v*Ec +H*gam1*t**2*v -H*gam1**2*t**2*v + gam1*t**2*v*Ec+gam1*Ec*kappa)

print("----")
print(" K33x    det7     ",K33x_d7)
print(" K33x    det4     ",K33x_d4)
print(" K33x    calc     ", K33x_c)

print("-----------------------------------------")


K43x_d7 = det7(dx,0.,0.,dy,0.,0.,0.,\
            0.,dx,0.,0.,dy,0.,0.,\
            0.,0.,0.,0.,0.,dy,0.,\
            a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
            a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
            a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
            a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)    
    
K43x_d4 = -dx**2*dy*det4(a4p1,  b1pta1,b2pta1,b4p1,  a4p2,  b1pta2,b2pta2,b4p2,\
                      a4p3, b1pta3,b2pta3,b4p3,  a4p4, b1pta4,b2pta4,b4p4)  

K43x_c =  dx**3*gam1*kappa*t**2*(-H*gam1 + (gam+1)*Ec)

print("----")
print(" K43x   det7       ",K43x_d7)
print(" K43x   det4       ",K43x_d4)
print(" K43x   calc       ", K43x_c)

print("-----------------------------------------")


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded dprhoE/dpx   --- ")
print("****************************************************************")

K14x_d7 =  det7(0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,0.,0.,0.,dy,\
                a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)   
    
K14x_d4 = dx**2*dy*det4(a1p1, b1p1,b2pta1,b3pta1,a1p2,  b1p2,b2pta2,b3pta2,\
                     a1p3,b1p3,b2pta3,b3pta3,  a1p4,  b1p4,b2pta4,b3pta4)


K14x_c =  dx**3*gam1*t*Ec*kappa*(u+t*v)*( H*(2-gam)  +gam1*Ec)

print(" ")
print(" K14x  det7        ",K14x_d7)
print(" K14x  det4        ",K14x_d4)
print(" K14x  calc        ",K14x_c)
print("-----------------------------------------")


K24x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,0.,0.,0.,dy,\
                a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)    
    
K24x_d4 = -dx**2*dy*det4(a2p1, b1pta1,b2p1,b3pta1,a2p2,  b1pta2,b2p2,b3pta2,\
                      a2p3,b1pta3,b2p3,b3pta3,a2p4, b1pta4,b2p4,b3pta4)
        

K24x_c = dx**3*t*kappa*(gam1*u**2 + v*kappa + gam1*t*u*v)*(gam1*Ec + H*(2-gam) )

print("----")
print(" K24x   det7      ",K24x_d7)
print(" K24x   det4      ",K24x_d4)
print(" K24x   calc      ",K24x_c)

print("-----------------------------------------")

K34x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,0.,0.,0.,0.,dy,\
             a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)   
         
K34x_d4 = dx**2*dy*det4(a3p1, b1pta1,b2pta1,b3p1,a3p2,  b1pta2,b2pta2,b3p2,\
                     a3p3,b1pta3,b2pta3,b3p3,a3p4, b1pta4,b2pta4,b3p4)    
    
K34x_c = dx**3*t*kappa*((u*kappa-gam1*t*v**2-gam1*u*v)*(gam1*Ec+H*(2-gam)))

print("----")
print(" K34x    det7      ",K34x_d7)
print(" K34x    det4      ",K34x_d4)
print(" K34x    calc      ",K34x_c)

print("-----------------------------------------")

K44x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,dx,0.,0.,dy,0.,\
             a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)   
    
K44x_d4 = dx**3*det4( b1pta1,b2pta1,b3pta1,b4p1,  b1pta2,b2pta2,b3pta2,b4p2,\
                  b1pta3,b2pta3,b3pta3,b4p3, b1pta4,b2pta4,b3pta4,b4p4)

K44x_c= dx**3*kappa*(-H*gam1*kappa - gam1*v*Ec - v*kappa**2 - gam1**2*t*u*Ec - gam1*t**2*v*Ec - gam1**2*t**2*v*Ec + H*gam1**2*t*u + H*gam1**2*t**2*v  )
print(" ")
print(" K44x    det7   ",K44x_d7)
print(" K44x    det4   ",K44x_d4)
print(" K44x    calc   ",K44x_c)
print("-----------------------------------------")


#########################################################################

print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprho/dpy   -- ")
print("****************************************************************")

K11y_d7 =  det7(0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,
             a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K11y_d4 = -dx**3*det4( a1p1,b2pta1,b3pta1,b4pta1,a1p2,b2pta2,b3pta2,b4pta2,\
                       a1p3,b2pta3,b3pta3,b4pta3, a1p4,b2pta4,b3pta4,b4pta4)
            
K11y_c = dx**3*kappa*(u*kappa**2 + gam1*u*2*Ec + gam1*t*v*Ec + gam1*t**2*u*Ec - H*gam1*(1+t**2)*u ) 

K11y_s28a  = dx**3*kappa*(u*kappa**2 + gam1*u*Ec + gam1*t*v*Ec + gam1*(t**2+1.)*u*Ec - H*gam1*(1+t**2)*u ) 

K11y_s28b  = dx**3*gam1*kappa*(u+t*v)*Ec 

print(" ")
print(" K11y  det7        ",K11y_d7)
print(" K11y  det4        ",K11y_d4)
print(" K11y  calc        ",K11y_c)
print(" K11y   s28a       ",K11y_s28a)
print(" K11y   s28b       ",K11y_s28b)
print("-----------------------------------------")


K21y_d7 =  det7(dx,0.,0.,0.,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K21y_d4  = dx**3*det4(a2p1,b2p1,b3pta1,b4pta1,a2p2,b2p2,b3pta2,b4pta2,\
                        a2p3,b2p3,b3pta3,b4pta3,a2p4,b2p4,b3pta4,b4pta4)


K21y_c= dx**3*kappa*(kappa*v*gam + 2*Ec*gam1)


print(" ")
print(" K21y  det7     ",K21y_d7)
print(" K21y  det4     ",K21y_d4)
print(" K21y  calc     ", K21y_c)
print("-----------------------------------------")

K31y_d7 =  det7(dx,0.,0.,0.,0.,0.,0.,\
                0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K31y_d4  = -dx**3*det4(a3p1,b2pta1,b3p1,b4pta1,a3p2,b2pta2,b3p2,b4pta2,\
                       a3p3,b2pta3,b3p3,b4pta3,a3p4,b2pta4,b3p4,b4pta4)

K31y_c = dx**3*kappa*(-gam1*v*(t*v+u)+ kappa*u)


print(" ")
print(" K31y   det7     ",K31y_d7)
print(" K31y   det4     ",K31y_d4)
print(" K31y   calc     ", K31y_c)
print("----------------------------------------- ")


K41y_d7 =  det7(dx,0.,0.,0.,0.,0.,0.,\
                0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
          a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
          a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
          a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
          a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K41y_d4 = dx**3*det4(a4p1,b2pta1,b3pta1,b4p1,a4p2,b2pta2,b3pta2,b4p2,\
                     a4p3,b2pta3,b3pta3,b4p3,a4p4,b2pta4,b3pta4,b4p4)

K41y_c = -dx**3*gam1*kappa*(t*v + u)


print(" ")
print(" K41y    det7    ",K41y_d7)
print(" K41y    det4    ",K41y_d4)
print(" K41y    calc    ",K41y_c)

print("-----------------------------------------")


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprhou/dpy   -- ")
print("****************************************************************")
    
K12y_d7 =  det7(0.,dx,0.,0.,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)   
    
K12y_d4 = -dx**3*det4(a1p1, b1p1,b3pta1,b4pta1,a1p2,  b1p2,b3pta2,b4pta2,\
                     a1p3,b1p3,b3pta3,b4pta3,  a1p4,  b1p4,b3pta4,b4pta4)
        
K12y_c=dx**3*gam1*Ec*kappa*( H*gam1 - Ec*(gam+1))


print(" ")
print(" K12y    det7       ",K12y_d7)
print(" K12y    det4       ",K12y_d4)
print(" K12y    calc       ",K12y_c)

print("-----------------------------------------")

    
K22y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)    

K22y_d4 = dx**3*det4(a2p1,  b1pta1,b3pta1,b4pta1, a2p2,  b1pta2,b3pta2,b4pta2,\
                     a2p3, b1pta3,b3pta3,b4pta3, a2p4, b1pta4,b3pta4,b4pta4)

K22y_c=dx**3*kappa*(Ec*gam1*(t*kappa -gam*u) +t**2*u**3  + 2*u*v**2 - 3*t*u**2*v + H*gam1*((gam-2)*u-t*kappa) )

print(" K22y   det7     ",K22y_d7)
print(" K22y   det4     ",K22y_d4)
print(" K22y   calc     ", K22y_c)
print("------------------------------------------")

K32y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,0.,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)   

K32y_d4 = -dx**3*det4(a3p1,  b1pta1,b3p1,b4pta1,  a3p2,  b1pta2,b3p2,b4pta2,\
                        a3p3, b1pta3,b3p3,b4pta3,  a3p4, b1pta4,b3p4,b4pta4)

K32y_c =dx**3*kappa*(-u**2*kappa + gam1*((gam+1)*v-t*u)*Ec + H*gam1*(t*u - gam1*v))

print(" K32y   det7     ",K32y_d7)
print(" K32y   det4     ",K32y_d4)
print(" K32y   c        ",K32y_c)
print("----------------------------------------")

K42y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)   
          
K42y_d4 = dx**3*det4(a4p1,  b1pta1,b3pta1,b4p1,  a4p2,  b1pta2,b3pta2,b4p2,\
                     a4p3, b1pta3,b3pta3,b4p3,  a4p4, b1pta4,b3pta4,b4p4)
    

K42y_c=(dx**3*gam1*kappa*( -H*gam1+Ec*(gam+1)))

print(" K42y   det7     ",K42y_d7)
print(" K42y   det4     ",K42y_d4)
print(" K42y   calc     ", K42y_c)


print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded dprhov/dpy   --- ")
print("****************************************************************")

K13y_d7 =  det7(0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)   
    
K13y_d4 = -dx**3*det4(a1p1, b1p1,b2pta1,b4pta1,a1p2,  b1p2,b2pta2,b4pta2,\
                      a1p3,b1p3,b2pta3,b4pta3,  a1p4,  b1p4,b2pta4,b4pta4)

K13y_c =  dx**3*gam1*Ec*kappa*t*(-H*gam1 + Ec*(gam+1))



print(" ")
print(" K13y    det7     ",K13y_d7)
print(" K13y    det4     ",K13y_d4)
print(" K13y    calc     ", K13y_c)

print("-----------------------------------------")
    
K23y_d7   =  det7(dx,0.,0.,0.,dy,0.,0.,\
                  0.,0.,dx,0.,0.,0.,0.,\
                  0.,0.,0.,dx,0.,0.,dy,\
                  a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
                  a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
                  a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
                  a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)   
            
K23y_d4 = dx**3*det4(a2p1, b1pta1,b2p1,b4pta1,a2p2, b1pta2,b2p2,b4pta2,\
                         a2p3,b1pta3,b2p3,b4pta3,a2p4, b1pta4,b2p4,b4pta4)
    
K23y_c = dx**3*kappa*( gam1*((gam+1)*t*u-v)*Ec + v**2*kappa + H*gam1*(v - gam1*t*u) )

print("----")
print(" K23y   det7      ",K23y_d7)
print(" K23y   det4      ",K23y_d4)
print(" K23y   calc      ",K23y_c)
print("-----------------------------------------")
    
K33y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)    
 
K33y_d4 =  -dx**3*det4( a3p1, b1pta1, b2pta1,b4pta1, a3p2,  b1pta2, b2pta2,b4pta2,\
                         a3p3,b1pta3, b2pta3,b4pta3, a3p4, b1pta4, b2pta4,b4pta4)     

K33y_c=dx**3*kappa*t*(H*gam1*(gam1*v-t*u) - 2*gam1*v*Ec - gam1**2*v*Ec + u**2*kappa + gam1*t*u*Ec)

print("----")
print(" K33y    det7     ",K33y_d7)
print(" K33y    det4     ",K33y_d4)
print(" K33y    calc     ",K33y_c)
print("-----------------------------------------")

K43y_d7 = det7(dx,0.,0.,0.,dy,0.,0.,\
               0.,dx,0.,0.,0.,dy,0.,\
               0.,0.,dx,0.,0.,0.,0.,\
            a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
            a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
            a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
            a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)    
    
K43y_d4 = dx**3*det4(a4p1,  b1pta1,b2pta1,b4p1,  a4p2,  b1pta2,b2pta2,b4p2,\
                      a4p3, b1pta3,b2pta3,b4p3,  a4p4, b1pta4,b2pta4,b4p4)

K43y_c =  (dx**3*gam1*kappa*t*(H*gam1 - (gam+1)*Ec))

print("----")
print(" K43y    det7       ",K43y_d7)
print(" K43y    det4       ",K43y_d4)
print(" K43y    calc       ",K43y_c)
print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded drhoE/dpy   --- ")
print("****************************************************************")

K14y_d7 =  det7(0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                0.,0.,0.,dx,0.,0.,0.,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)   
    
K14y_d4 = -dx**3*det4(a1p1,b1p1,b2pta1,b3pta1,a1p2,  b1p2,b2pta2,b3pta2,\
                      a1p3,b1p3,b2pta3,b3pta3,  a1p4,  b1p4,b2pta4,b3pta4)

K14y_c= -dx**3 *gam1 *Ec* kappa * (u+t*v)*(gam1*Ec+H*(2-gam))

print(" ")
print(" K14y    det7       ",K14y_d7)
print(" K14y    det4       ",K14y_d4)
print(" K14y    calc       ",K14y_c)

print("-----------------------------------------")

K24y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                0.,0.,0.,dx,0.,0.,0.,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)  
    
K24y_d4 =  dx**3*det4(a2p1, b1pta1,b2p1,b3pta1,a2p2,  b1pta2,b2p2,b3pta2,\
                      a2p3,b1pta3,b2p3,b3pta3,a2p4, b1pta4,b2p4,b3pta4)
        

K24y_c= -dx**3 * kappa*(2*Ec*gam1 + gam*kappa*v)*(gam1*Ec + H*(2-gam))

print("----")
print(" K24y   det7      ",K24y_d7)
print(" K24y   det4      ",K24y_d4)
print(" K24y   calc      ",K24y_c)

print("-----------------------------------------")

K34y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,0.,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)  
                 
K34y_d4 = -dx**3*det4(a3p1, b1pta1,b2pta1,b3p1,a3p2,  b1pta2,b2pta2,b3p2,\
                     a3p3,b1pta3,b2pta3,b3p3,a3p4, b1pta4,b2pta4,b3p4)    
    

K34y_c=dx**3*kappa*(-u*kappa + gam1*t*v**2 + gam1*u*v)*(gam1*Ec +H*(2-gam))

print("----")
print(" K34y    det7      ",K34y_d7)
print(" K34y    det4      ",K34y_d4)
print(" K34y    calc       ",K34y_c)
print("-----------------------------------------")

K44y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)  
    
K44y_d4 = dx**3*det4(a4p1,   b1pta1,b2pta1,b3pta1,a4p2,   b1pta2,b2pta2,b3pta2,\
                      a4p3,  b1pta3,b2pta3,b3pta3,a4p4,  b1pta4,b2pta4,b3pta4)
    

K44y_c= dx**3 * kappa * (u*kappa**2 + gam*gam1*u*Ec + gam1*t**2*u*Ec + gam1**2*t*v*Ec -H*gam1**2*u - H*gam1**2*t*v - H*gam1*t**2*u +H*gam1*t*v )
print(" ")
print(" K44y    det7    ",K44y_d7)
print(" K44y    det4    ",K44y_d4)
print(" K44y    calc    ",K44y_c)
print("-----------------------------------------")
#########################################################################

print("  ")
print(" **************************************************************** ")
print("    ratio of corresponding Kx Ky coefficients  ")
print(" **************************************************************** ")
print("  -t=-dy/dx       = ",(-dy/dx))
print(" -------- -  -------   -----   --------  ")
print(" K11x/K11y  det7     ",K11x_d7/K11y_d7)
print(" K21x/K21y  det7     ",K21x_d7/K21y_d7)
print(" K31x/K31y  det7     ",K31x_d7/K31y_d7)
print(" K41x/K41y  det7     ",K41x_d7/K41y_d7)
print(" -------- -  -------   -----   --------  ")
print(" K12x/K12y  det7     ",K12x_d7/K12y_d7)
print(" K22x/K22y  det7     ",K22x_d7/K22y_d7)
print(" K32x/K32y  det7     ",K32x_d7/K32y_d7)
print(" K42x/K42y  det7     ",K42x_d7/K42y_d7)
print(" -------- -  -------   -----   --------  ")
print(" K13x/K13y  det7     ",K13x_d7/K13y_d7)
print(" K23x/K23y  det7     ",K23x_d7/K23y_d7)
print(" K33x/K33y  det7     ",K33x_d7/K33y_d7)
print(" K43x/K43y  det7     ",K43x_d7/K43y_d7)
print(" -------- -  -------   -----   --------  ")
print(" K14x/K14y  det7     ",K14x_d7/K14y_d7)
print(" K24x/K24y  det7     ",K24x_d7/K24y_d7)
print(" K34x/K34y  det7     ",K34x_d7/K34y_d7)
print(" K44x/K44y  det7     ",K44x_d7/K44y_d7)
print(" -------- -  -------   -----   --------  ")


#########################################################################

print( " ")
print("****************************************************************")
print("    denominator's determinant                 ")
print("  link with eigenvalues and coefficients     ")
print("****************************************************************")

# we do not code a det in dimension 8 but rather use the first line
# expansion of the det
#
#
DETDENOM_L1 =  dx*det7(dx,0.,0.,0.,dy,0.,0.,\
                    0.,dx,0.,0.,0.,dy,0.,\
                    0.,0.,dx,0.,0.,0.,dy,\
                    a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                    a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                    a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                    a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)\
          +dy*det7(0.,dx,0.,0.,dy,0.,0.,\
                   0.,0.,dx,0.,0.,dy,0.,\
                   0.,0.,0.,dx,0.,0.,dy,\
                   a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
                   a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
                   a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
                   a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)
#
DETDENOM_K1 =  dx*K11x_d7 + dy*K11y_d7

DETDENOM_K2 =  dx*K22x_d7 + dy*K22y_d7

DETDENOM_K3 =  dx*K33x_d7 + dy*K33y_d7

DETDENOM_K4 =  dx*K44x_d7 + dy*K44y_d7


    
print("-----------------------------------------------------")
print(' denominator det from line 1                ',DETDENOM_L1)
print(' denominator det from line 1 using K coeffs ',DETDENOM_K1)
print("-----------------------------------------------------")
print(' denominator det from line 2 using K coeffs ',DETDENOM_K2)
print(' denominator det from line 3 using K coeffs ',DETDENOM_K3)
print(' denominator det from line 4 using K coeffs ',DETDENOM_K4)
print("----------------")

print(" ")
print("**********************************************************")
print(" print null differential forms ")
print("**********************************************************")
print("          --------------------")
print(" ",round(K11x_d7,3)," drho -",round(K21x_d7,3)," drhou +",round(K31x_d7,3)," drhov -",round(K41x_d7,3)," drhoE = 0")
print(" ",round(K12x_d7,3)," drho -",round(K22x_d7,3)," drhou +",round(K32x_d7,3)," drhov -",round(K42x_d7,3)," drhoE = 0")
print(" ",round(K13x_d7,3)," drho -",round(K23x_d7,3)," drhou +",round(K33x_d7,3)," drhov -",round(K43x_d7,3)," drhoE = 0")
print(" ",round(K14x_d7,3)," drho -",round(K24x_d7,3)," drhou +",round(K34x_d7,3)," drhov -",round(K44x_d7,3)," drhoE = 0")

print(" ",round(K11y_d7,3)," drho -",round(K21y_d7,3)," drhou +",round(K31y_d7,3)," drhov +",round(K41y_d7,3)," drhoE = 0")
print(" ",round(K12y_d7,3)," drho -",round(K22y_d7,3)," drhou +",round(K32y_d7,3)," drhov +",round(K42y_d7,3)," drhoE = 0")
print(" ",round(K13y_d7,3)," drho -",round(K23y_d7,3)," drhou +",round(K33y_d7,3)," drhov +",round(K43y_d7,3)," drhoE = 0")
print(" ",round(K14y_d7,3)," drho -",round(K24y_d7,3)," drhou +",round(K34y_d7,3)," drhov +",round(K44y_d7,3)," drhoE = 0")


print("   ")
print(" print scaled null differential forms  ")
print(" -------------------------------------------")
print(" ",round(K11x_d7,3)," drho -",round(K21x_d7,3)," drhou +",round(K31x_d7,3)," drhov -",round(K41x_d7,3)," drhoE = 0")
c = K11x_d7/K12x_d7
print(" ",round(K12x_d7*c,3)," drho -",round(K22x_d7*c,3)," drhou +",round(K32x_d7*c,3)," drhov -",round(K42x_d7*c,3)," drhoE = 0")
c = K11x_d7/K13x_d7
print(" ",round(K13x_d7*c,3)," drho -",round(K23x_d7*c,3)," drhou +",round(K33x_d7*c,3)," drhov -",round(K43x_d7*c,3)," drhoE = 0")
c = K11x_d7/K14x_d7
print(" ",round(K14x_d7*c,3)," drho -",round(K24x_d7*c,3)," drhou +",round(K34x_d7*c,3)," drhov -",round(K44x_d7*c,3)," drhoE = 0")

c = K11x_d7/K11y_d7
print(" ",round(K11y_d7*c,3)," drho -",round(K21y_d7*c,3)," drhou +",round(K31y_d7*c,3)," drhov -",round(K41y_d7*c,3)," drhoE = 0")
c = K11x_d7/K12y_d7
print(" ",round(K12y_d7*c,3)," drho -",round(K22y_d7*c,3)," drhou +",round(K32y_d7*c,3)," drhov -",round(K42y_d7*c,3)," drhoE = 0")
c = K11x_d7/K13y_d7
print(" ",round(K13y_d7*c,3)," drho -",round(K23y_d7*c,3)," drhou +",round(K33y_d7*c,3)," drhov -",round(K43y_d7*c,3)," drhoE = 0")
c = K11x_d7/K14y_d7
print(" ",round(K14y_d7*c,3)," drho -",round(K24y_d7*c,3)," drhou +",round(K34y_d7*c,3)," drhov -",round(K44y_d7*c,3)," drhoE = 0")
print("     ")
print("     ")

####################################################################################################
#  simplified differential form of the characteristics §3.4 (39)
##########################################################################################"

KK1 = gam1*Ec*(u+t*v)
KK2 = -(gam*u*(u+t*v)-2.*Ec)
KK3 = -(gam*v*(u+t*v)-2.*Ec*t)
KK4 = gam1*(u+t*v)

print(" ")
print("******************************************************")
print(" simplified characteristic equation § 3.4 (39) ")
print("******************************************************")
print("  ")
print(" ",round(KK1,3)," drho +",round(KK2,3)," drhou +",round(KK3,3)," drhov +",round(KK4,3)," drhoE = 0")
print(" ")
print("   scaled")
print("  ")
c = K11x_d7/KK1
print(" ",round(KK1*c,3)," drho +",round(KK2*c,3)," drhou +",round(KK3*c,3)," drhov +",round(KK4*c,3)," drhoE = 0")
#                                      

print(" ")
print("**********************************************************")
print("  (10) in conservative variables  ")
print("**********************************************************")

sqm = np.sqrt(M**2-1.)

d10_drho = gam1*Ec*sqm
d10_drou = -(v+gam1*sqm*u)
d10_drov = u - gam1*sqm*v
d10_droE = gam1*sqm

print("  ")
print(" ",round(d10_drho,3)," drho +",round(d10_drou,3)," drhou +",round(d10_drov,3)," drhov +",round(d10_droE,3)," drhoE = 0")
c= K11x_d7/d10_drho
print("  ")
print("   scaled")
print("  ")
print(" ",round(d10_drho*c,3)," drho +",round(d10_drou*c,3)," drhou +",round(d10_drov*c,3)," drhov +",round(d10_droE*c,3)," drhoE = 0")



print(" ")
print("**********************************************************")
print("  ratio between the terms of (39) and (10)  ")
print("**********************************************************")
print( " ")
print(" drho  terms ",KK1/d10_drho)
print(" drhou terms ",KK2/d10_drou)
print(" drhov terms ",KK3/d10_drov)
print(" drhoE terms ",KK4/d10_droE)
print(" ------------------------------")
print(" (u+vt)tan(beta) ",(u+t*v)*np.tan(bet))
print(" ------------------------------")