#######################################################################################################
#### Title: Adjoint and direct characteristic equations for two-dimensional compressible Euler flows
#### Authors: Kevin Ancourt, Jacques Peter, Oliver Atinault
#######################################################################################################

import numpy as np
from determinants_dim_2_7 import *
import sympy as sp 

print(" ------------------------------------------------------------------")
print("   the oK variables stand for the \overline{K} coefficients" )
print("     in the manuscript  ")
print(" -----------------------------------------------------------------")
print("   ")
print("   ")
gam = 1.4
gam1 = gam - 1.
#-----------------------
#
ro = 0.55
p  = 1.12
c  = np.sqrt(gam*p/ro)
M  = 1.55
nx = .32                          # (nx,ny) unit vector
ny = np.sqrt(1.-nx**2)              # + or -  
#

#------------------------
#
u  = M*nx*c            # (dx,dy) and (u,v) along the same direction
v  = M*ny*c
Ec = 0.5*(u**2+v**2)
H  = Ec + gam/(gam-1.)*p/ro 
#
#--------------------------------
#
dx =  nx                # (dx,dy) and (u,v) along the same direction
dy =  ny
t  = dy/dx
kappa  = u*t-v # w = kappa
#
print(" ********************************************************** ")
print("  Kappa (null for stream trace) =  ",kappa )      
print(" ********************************************************** ")
#
#----------------------------------------------------------------------
#
#-----------------------------------------------------------------------

a1p1 =  0. #a1p1 = a1p1 /a11
a1p2 = gam1 * Ec - u**2
a1p3 =  -u*v
a1p4 = (gam1*Ec-H)*u

a2p1 = 1.
a2p2 = (3-gam)*u
a2p3 = v
a2p4 = (H-gam1*u**2)

a3p1 = 0.
a3p2 = -gam1 *v
a3p3 = u
a3p4 = -gam1 * u * v 

a4p1 = 0.
a4p2 = gam1
a4p3 = 0.
a4p4 = gam*u

#-----------------------------------------------

b1p1 = 0.
b1p2 =  -u*v
b1p3 = gam1*Ec-v**2
b1p4 =(gam1*Ec-H)*v

b2p1 =0. 
b2p2 = v
b2p3 = -gam1*u
b2p4 = -gam1*u*v

b3p1 = 1.
b3p2 =  u
b3p3 = (3-gam)*v
b3p4 = H-gam1 * v**2

b4p1 = 0.
b4p2 = 0.
b4p3 = gam1
b4p4 = gam*v

#-----------------------------------------------------
b1pta1 = 0. 
b1pta2 = u*kappa - t*gam1*Ec #-u*v -t * (gam1*Ec-u**2)
b1pta3 =gam1 * Ec + v* kappa #  gam1 *Ec - v**2 + t*u*v
b1pta4 = -kappa * (gam1*Ec - H) #(gam1*Ec -H)*v -u*t*(gam1*Ec -H)


b2pta1 = -t 
b2pta2 =  v - t*u*(3-gam)
b2pta3 = -gam1*u - t*v 
b2pta4 = gam1*u*kappa -t*H

b3pta1 = 1.
b3pta2 = u+t*gam1*v
b3pta3 = (3-gam)*v - t*u
b3pta4 =  H + gam1*v*kappa

b4pta1 = 0.
b4pta2 = -t*gam1
b4pta3 = gam1 
b4pta4 = -gam*kappa


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprho/dpx   -- ")
print("****************************************************************")

 
K11x_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K11x_d4 = dx**3 * det4( b1p1,b2pta1,b3pta1,b4pta1, b1p2,b2pta2,b3pta2,b4pta2,\
                  b1p3,b2pta3,b3pta3,b4pta3, b1p4,b2pta4,b3pta4,b4pta4)
    

K11x_d3 = dx**3 *t * det3(-u*v,u+t*gam1*v , -t*gam1, \
                          gam1*Ec -v**2 , (3-gam)*v - t*u , gam1 , \
                          (gam1*Ec-H)*v, H+gam1*v*kappa ,-gam*kappa )    + dx**3 * det3(-u*v , v- t*u*(3-gam), -t*gam1 , gam1*Ec-v**2, -gam1*u -t*v , gam1,\
                                                                                (gam1*Ec-H)*v , gam1*u*kappa -t*H , - gam*kappa)    

K11x_c = -dx **3*kappa*(v*kappa**2 -H*gam1*v - H*gam1*t**2*v + gam1*Ec*(u*t+v)+ gam1*t**2*2*Ec*v) 

oK11x_c = -dx **2*(v*kappa**2 -H*gam1*v - H*gam1*t**2*v + gam1*Ec*(u*t+v)+ gam1*t**2*2*Ec*v)


oK11x_s =  -dx*dy*gam1*(-H*u*(1+t**2) + 2.*Ec*(u+t*v))
print(" ")
print(" K11x  det7     ",K11x_d7)
print(" K11x  det4     ",K11x_d4)
print(" K11x  det3     ",K11x_d3)
print("----")
print(" K11x  calc     ",K11x_c)
print("----")
print(" oK11x  calc     ",oK11x_c)
print(" oK11x  simp     ",oK11x_s)

print("-----------------------------------------")


K21x_d7 =  det7(0.,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,0.,dy,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K21x_d4  = -dx**2*dy*det4(a2p1,b2p1,b3pta1,b4pta1,a2p2,b2p2,b3pta2,b4pta2,\
                       a2p3,b2p3,b3pta3,b4pta3,a2p4,b2p4,b3pta4,b4pta4)

K21x_c = -dx**2 * dy * kappa * (gam*kappa*v +2*Ec * (gam-1))

oK21x_c = -dx*dy*(gam*kappa*v +2*Ec * (gam-1))

oK21x_s = -dx*dy*2.*Ec * (gam-1)

print(" ")
print(" K21x  det7     ",K21x_d7)
print(" K21x  det4     ",K21x_d4)
print(" K21x  c        ",K21x_c)
print(" ------ ")
print(" oK21x  c       ",oK21x_c)
print(" oK21x  s       ",oK21x_s)

print("-----------------------------------------")


K31x_d7 =  det7(0.,0.,0.,dy,0.,0.,0.,\
             dx,0.,0.,0.,dy,0.,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K31x_d4  = dx**2*dy*det4(a3p1,b2pta1,b3p1,b4pta1,a3p2,b2pta2,b3p2,b4pta2,\
                      a3p3,b2pta3,b3p3,b4pta3,a3p4,b2pta4,b3p4,b4pta4)


K31x_c = dx**2*dy*kappa*(-2*Ec*t + gam*v*(t*v+u))

oK31x_s = dx*dy*(-2*Ec*t + gam*v*(t*v+u))

print(" ")
print(" K31x   det7     ",K31x_d7)
print(" K31x   det4a    ",K31x_d4)
print(" K31x   c        ", K31x_c)
print(" oK31x   s       ", oK31x_s)
print("-----------------------------------------")


K41x_d7 =  det7(0.,0.,0.,dy,0.,0.,0.,\
             dx,0.,0.,0.,dy,0.,0.,\
             0.,dx,0.,0.,0.,dy,0.,\
             a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a2p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)  
    
K41x_d4 = -dx**2*dy*det4(a4p1,b2pta1,b3pta1,b4p1,a4p2,b2pta2,b3pta2,b4p2,\
                      a4p3,b2pta3,b3pta3,b4p3,a4p4,b2pta4,b3pta4,b4p4)
    
  
K41x_c = dx**2 * dy * kappa *gam1 *(t*v+u)

oK41x_c = dx*dy*gam1 *(t*v+u)

print(" ")
print(" K41x    det7    ",K41x_d7)
print(" K41x    det4    ",K41x_d4)
print(" K41x     c      ",K41x_c)
print(" oK41x    c      ",oK41x_c)

print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprhou/dpx  -- ")
print("****************************************************************")
    
K12x_d7 =  det7(0.,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)   
    
K12x_d4 = dx**2*dy*det4(a1p1, b1p1,b3pta1,b4pta1,a1p2,  b1p2,b3pta2,b4pta2,\
                        a1p3,b1p3,b3pta3,b4pta3,  a1p4,  b1p4,b3pta4,b4pta4)
        
K12x_c = dx**2*dy*gam1*Ec*kappa*( -H*gam1 + (gam+1)*Ec)

#K12x_s = Ec*dx**2*dy*gam1*kappa * (-H*gam + H +gam*Ec +Ec)

oK12x_s  = dx*dy*gam1 *Ec* (-H*gam1 +(gam+1)*Ec)


print(" ")
print(" K12x det7       ",K12x_d7)
print(" K12x det4       ",K12x_d4)
print(" K12x_c          ",K12x_c)
print(" --- ")
print(" oK12x_s         ",oK12x_s)
print("-----------------------------------------")


    
K22x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)    

K22x_d4 = dx**3*det4( b1pta1, b2p1,b3pta1,b4pta1,  b1pta2, b2p2,b3pta2,b4pta2,\
                     b1pta3, b2p3,b3pta3,b4pta3,  b1pta4, b2p4,b3pta4,b4pta4)
    

K22x_c =  dx**3*kappa*(-Ec*gam1**2*t*u + Ec*gam1*v - H*gam1**2*t*u + H*gam1*v + gam1**2*kappa*u**2 + gam1**2*t*u*v**2 + gam1**2*u**2*v + gam1*kappa*2*Ec + kappa*v**2)

K22x_s = dx**3 * kappa * (gam1**2*t*u*Ec + gam1*Ec*kappa + v**2*kappa + H*gam1*v -H*gam1**2*t*u+gam1*t*u*Ec)

oK22x_s = dx**2 * (gam1**2*t*u*Ec + gam1*Ec*kappa + v**2*kappa + H*gam1*v -H*gam1**2*t*u+gam1*t*u*Ec)

print(" K22x   det7    ",K22x_d7)
print(" K22x   det4    ",K22x_d4)
print(" K22x    c      ",K22x_c )
print(" K22x    s      ",K22x_s )
print(" oK22x    s     ",oK22x_s )

print("------------------------------------------")

K32x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,0.,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)   

K32x_d4 = dx**2*dy*det4(a3p1,  b1pta1,b3p1,b4pta1,  a3p2,  b1pta2 ,b3p2,b4pta2,\
                        a3p3,  b1pta3,b3p3,b4pta3,  a3p4,  b1pta4,b3p4,b4pta4)

K32x_c = dx**2*dy*kappa*(Ec*gam1**2*v - Ec*gam1*kappa - Ec*gam1*v + H*gam1**2*v - H*gam1*kappa - H*gam1*v - 2*gam1**2*Ec*v+ 2*gam1*kappa*Ec+ kappa*u**2)

K32x_s = dx**2*dy*kappa*(H*gam1**2*v - gam1*v*Ec - gam1**2*v*Ec + u**2*kappa + gam1*kappa*Ec - H*gam1*t*u)

oK32x_s = dx*dy*(H*gam1**2*v - gam1*v*Ec - gam1**2*v*Ec - H*gam1*t*u)


print(" K32x   det7    ",K32x_d7)
print(" K32x   det4    ",K32x_d4)
print(" K32x    c      ",K32x_c)
print(" K32x    s      ",K32x_s)
print(" oK32x    s     ",oK32x_s)
print("----------------------------------------")


K42x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                a1p1,a3p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a3p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a3p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a3p4,a4p4,b1p4,b2p4,b3p4,b4p4)   
      
    
K42x_d4 = -dx**2*dy*det4(a4p1,   b1pta1,b3pta1,b4pta1,  a4p2,   b1pta2,b3pta2,b4pta2,\
                         a4p3,  b1pta3,b3pta3,b4pta3,  a4p4,  b1pta4,b3pta4,b4pta4)
    

K42x_c =  dx**2*dy*gam1*kappa*( H*gam1 - (gam+1)*Ec)

oK42x_c =  dx*dy*gam1*( H*gam1 - (gam+1)*Ec)
 
print(" K42x   det7    ",K42x_d7)
print(" K42x   det4    ",K42x_d4)
print(" K42x    c      ", K42x_c )
print(" oK42x    c     ", oK42x_c )
print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded dprhov/dpx   --- ")
print("****************************************************************")


K13x_d7 =  det7(0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,0.,0.,0.,dy,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)   
    
K13x_d4 = dx**2*dy*det4(a1p1, b1p1,b2pta1,b4pta1,a1p2,  b1p2,b2pta2,b4pta2,\
                      a1p3,b1p3,b2pta3,b4pta3,  a1p4,  b1p4,b2pta4,b4pta4)

K13x_c = dx**2*dy*gam1*kappa*t*Ec*(H*gam1 - (gam+1)*Ec)

oK13x_s = dx*dy*gam1*t*Ec*(H*gam1 - (gam+1)*Ec)


print(" ")
print(" K13x    det7     ",K13x_d7)
print(" K13x    det4     ",K13x_d4)
print(" K13x    c        ", K13x_c )
print(" --- ")
print(" oK13x    s       ", oK13x_s )
print("-----------------------------------------")

K23x_d7   =  det7(dx,0.,0.,dy,0.,0.,0.,\
                  0.,0.,0.,0.,0.,dy,0.,\
                  0.,0.,dx,0.,0.,0.,dy,\
                  a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
                  a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
                  a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
                  a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)    

K23x_d4 = -dx**2*dy*det4(a2p1, b1pta1,b2p1,b4pta1,a2p2, b1pta2,b2p2,b4pta2,\
                         a2p3,b1pta3,b2p3,b4pta3,a2p4, b1pta4,b2p4,b4pta4)
    

K23x_c =dx **2*dy*kappa*(-v**2*kappa - gam1*kappa*Ec - gam1**2*t*u *Ec - H*gam1*v + H*gam1**2*t*u -gam1*t*u*Ec )

oK23x_s = dx*dy*(-v**2*kappa - gam1*kappa*Ec - gam1**2*t*u *Ec - H*gam1*v + H*gam1**2*t*u -gam1*t*u*Ec )
 

print("----")
print(" K23x   det7      ",K23x_d7)
print(" K23x   det4      ",K23x_d4)
print(" K23x   c         ",K23x_c)
print(" oK23x            ",oK23x_s)
print("-----------------------------------------")
K33x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)    
 

        
K33x_d4 =  dx**3*det4(  b1pta1, b2pta1,b3p1,b4pta1,  b1pta2, b2pta2,b3p2,b4pta2,\
                       b1pta3, b2pta3,b3p3,b4pta3, b1pta4, b2pta4,b3p4,b4pta4)
    
K33x_c = dx **3*kappa*(gam1 **2*v **3 - 2*kappa **2*v - kappa*v **2 + gam1*kappa*2*Ec + 2*gam1 **2*kappa*v **2 + gam1 **2*kappa **2*v - Ec*gam1*kappa - H*gam1*kappa + gam1 **2*t **2*v **3 + Ec*gam1*t **2*v + H*gam1*t **2*v - Ec*gam1 **2*t **2*v - H*gam1 **2*t **2*v)

K33x_s = dx **3*kappa*(-v**3 + 3*t*u*v**2 -H*gam1*kappa - 2*t**2*u**2*v+gam1**2*t**2*v*Ec +H*gam1*t**2*v -H*gam1**2*t**2*v + gam1*t**2*v*Ec+gam1*Ec*kappa)

oK33x_s = dx**2 *(-v**3 + 3*t*u*v**2 -H*gam1*kappa - 2*t**2*u**2*v+gam1**2*t**2*v*Ec +H*gam1*t**2*v -H*gam1**2*t**2*v + gam1*t**2*v*Ec+gam1*Ec*kappa)

print("----")
print(" K33x    det7     ",K33x_d7)
print(" K33x    det4     ",K33x_d4)
print(" K33x    c        ", K33x_c)
print(" K33x    s        ", K33x_s)
print(" oK33x    s       ", oK33x_s)

print("-----------------------------------------")


K43x_d7 = det7(dx,0.,0.,dy,0.,0.,0.,\
            0.,dx,0.,0.,dy,0.,0.,\
            0.,0.,0.,0.,0.,dy,0.,\
            a1p1,a2p1,a4p1,b1p1,b2p1,b3p1,b4p1,\
            a1p2,a2p2,a4p2,b1p2,b2p2,b3p2,b4p2,\
            a1p3,a2p3,a4p3,b1p3,b2p3,b3p3,b4p3,\
            a1p4,a2p4,a4p4,b1p4,b2p4,b3p4,b4p4)    
    
K43x_d4 = -dx**2*dy*det4(a4p1,  b1pta1,b2pta1,b4p1,  a4p2,  b1pta2,b2pta2,b4p2,\
                      a4p3, b1pta3,b2pta3,b4p3,  a4p4, b1pta4,b2pta4,b4p4)  

K43x_c =  dx**2*dy*gam1*kappa*t*(-H*gam1 + (gam+1)*Ec)
oK43x_c =  dx*dy*gam1*t*(-H*gam1 + (gam+1)*Ec)

print("----")
print(" K43x   det7       ",K43x_d7)
print(" K43x   det4       ",K43x_d4)
print(" K43x    c         ", K43x_c)
print(" oK43x    c        ", oK43x_c)
print("-----------------------------------------")


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded dprhoE/dpx  --- ")
print("****************************************************************")

K14x_d7 =  det7(0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,0.,0.,0.,dy,\
                a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)   
    
K14x_d4 = dx**2*dy*det4(a1p1, b1p1,b2pta1,b3pta1,a1p2,  b1p2,b2pta2,b3pta2,\
                     a1p3,b1p3,b2pta3,b3pta3,  a1p4,  b1p4,b2pta4,b3pta4)


K14x_c =  dx**2*dy*gam1*kappa*(u+t*v)*Ec*( H*(2-gam)  +gam1*Ec)
oK14x_c =  dx*dy*gam1*Ec*(u+t*v)*( H*(2-gam)  +gam1*Ec)

print(" ")
print(" K14x  det7        ",K14x_d7)
print(" K14x  det4        ",K14x_d4)
print(" K14x  c           ",K14x_c)
print(" oK14x  c          ",oK14x_c)
print("-----------------------------------------")


K24x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,0.,0.,0.,dy,\
                a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)    
    
K24x_d4 = -dx**2*dy*det4(a2p1, b1pta1,b2p1,b3pta1,a2p2,  b1pta2,b2p2,b3pta2,\
                      a2p3,b1pta3,b2p3,b3pta3,a2p4, b1pta4,b2p4,b3pta4)
        

K24x_c = dx**2*dy*kappa*(gam1*u**2 + v*kappa + gam1*t*u*v)*(gam1*Ec + H*(2-gam) )
oK24x_c = dx*dy*(gam1*u**2 + v*kappa + gam1*t*u*v)*(gam1*Ec + H*(2-gam) )

print("----")
print(" K24x   det7      ",K24x_d7)
print(" K24x   det4      ",K24x_d4)
print(" K24x  c          ",K24x_c)
print(" oK24x  c         ",oK24x_c)

print("-----------------------------------------")

K34x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,0.,0.,0.,0.,dy,\
             a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)   
         
K34x_d4 = dx**2*dy*det4(a3p1, b1pta1,b2pta1,b3p1,a3p2,  b1pta2,b2pta2,b3p2,\
                     a3p3,b1pta3,b2pta3,b3p3,a3p4, b1pta4,b2pta4,b3p4)    
    
K34x_c = dx**2*dy*kappa*(1.0*Ec*gam1**2*t*v**2 + 1.0*Ec*gam1**2*u*v - 1.0*Ec*gam1*kappa*u + 1.0*H*gam1**2*t*v**2 + 1.0*H*gam1**2*u*v - 1.0*H*gam1*kappa*u - 1.0*H*gam1*t*v**2 - 1.0*H*gam1*u*v + 1.0*H*kappa*u - 1.0*gam1**2*kappa*u*v**2 - 1.0*gam1**2*t*v**4 - 1.0*gam1**2*u**3*v - 2.0*gam1**2*u*v**3 + 1.0*gam1*kappa*u**3 + 1.0*gam1*kappa*u*v**2)

K34x_s = dx**2*dy*kappa*((u*kappa-gam1*t*v**2-gam1*u*v)*(gam1*Ec+H*(2-gam)))

oK34x_s = dx*dy*((u*kappa-gam1*t*v**2-gam1*u*v)*(gam1*Ec+H*(2-gam)))

print("----")
print(" K34x    det7      ",K34x_d7)
print(" K34x    det4      ",K34x_d4)
print(" K34x  c           ",K34x_c)
print(" K34x  s           ",K34x_s)
print(" oK34x  s          ",oK34x_s)
print("-----------------------------------------")

K44x_d7 =  det7(dx,0.,0.,dy,0.,0.,0.,\
             0.,dx,0.,0.,dy,0.,0.,\
             0.,0.,dx,0.,0.,dy,0.,\
             a1p1,a2p1,a3p1,b1p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,b1p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,b1p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,b1p4,b2p4,b3p4,b4p4)   
    
K44x_d4 = dx**3*det4( b1pta1,b2pta1,b3pta1,b4p1,  b1pta2,b2pta2,b3pta2,b4p2,\
                  b1pta3,b2pta3,b3pta3,b4p3, b1pta4,b2pta4,b3pta4,b4p4)

K44x_c =   dx**3*kappa*(1.0*Ec*gam1**2*kappa + 1.0*Ec*gam1**2*t**2*v + 1.0*Ec*gam1**2*v + 1.0*Ec*gam1*t**2*v + 1.0*Ec*gam1*v + 1.0*H*gam1**2*kappa + 1.0*H*gam1**2*t**2*v + 1.0*H*gam1**2*v - 1.0*H*gam1*kappa - 1.0*gam1**2*kappa**2*v - 1.0*gam1**2*kappa*u**2 - 3.0*gam1**2*kappa*v**2 - 1.0*gam1**2*t**2*v**3 - 1.0*gam1**2*u**2*v - 2.0*gam1**2*v**3 - 1.0*gam1*kappa**2*v - 2.0*gam1*kappa*v**2 - 1.0*gam1*t**2*v**3 - 1.0*gam1*u**2*v - 2.0*gam1*v**3 - 1.0*kappa**2*v)

K44x_s = dx**3*kappa*(-H*gam1*kappa - gam1*v*Ec - v*kappa**2 - gam1**2*t*u*Ec - gam1*t**2*v*Ec - gam1**2*t**2*v*Ec + H*gam1**2*t*u + H*gam1**2*t**2*v  )

oK44x_s = dx**2*(-gam1*v*Ec -gam1**2*t*u*Ec -gam1*t**2*v*Ec -gam1**2*t**2*v*Ec + H*gam1**2*t*u + H*gam1**2*t**2*v  )

print(" ")
print(" K44x_d7    det7   ",K44x_d7)
print(" K44x_d7    det4   ",K44x_d4)
print(" K44x  c           ",K44x_c)
print(" K44x  s           ",K44x_s)
print(" oK44x  s          ",oK44x_s)
print("-----------------------------------------")


#########################################################################

print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprho/dpy   -- ")
print("****************************************************************")

K11y_d7 =  det7(0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,
             a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K11y_d4 = -dx**3*det4( a1p1,b2pta1,b3pta1,b4pta1,a1p2,b2pta2,b3pta2,b4pta2,\
                       a1p3,b2pta3,b3pta3,b4pta3, a1p4,b2pta4,b3pta4,b4pta4)
            
K11y_c =  dx**3*kappa*(-Ec*gam1*kappa*t - H*gam1*kappa*t - H*gam1*t*v - H*gam1*u + gam1*kappa**2*u + 1.0*gam1*kappa*t*v**2 + 2.0*gam1*kappa*u*v + 1.0*gam1*t*v**3 + 1.0*gam1*u**3 + 2.0*gam1*u*v**2 + 1.0*kappa**2*u)

K11y_s = dx**3*kappa*(u*kappa**2 + gam1*u*2*Ec + gam1*t*v*Ec + gam1*t**2*u*Ec - H*gam1*(1+t**2)*u ) 

oK11y_a = dx**2*gam1*(u*2*Ec + t*v*Ec + t**2*u*Ec - H*(1+t**2)*u ) 

oK11y_s = dx**2*gam1*(1+t**2)*u*(2*Ec - H)
#
print(" ")

print(" K11y  det7        ",K11y_d7)
print(" K11y  det4        ",K11y_d4)
print(" K11y   c          ",K11y_c)
print(" K11y   s          ",K11y_s)
print(" oK11y   a4        ",oK11y_a)
print(" oK11y   s         ",oK11y_s)
print("-----------------------------------------")


K21y_d7 =  det7(dx,0.,0.,0.,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K21y_d4  = dx**3*det4(a2p1,b2p1,b3pta1,b4pta1,a2p2,b2p2,b3pta2,b4pta2,\
                        a2p3,b2p3,b3pta3,b4pta3,a2p4,b2p4,b3pta4,b4pta4)


K21y_c= dx**3*kappa*(kappa*v*gam + 2*Ec*gam1)

oK21y_c= dx**2*gam1* 2*Ec

print(" ")
print(" K21y  det7     ",K21y_d7)
print(" K21y  det4     ",K21y_d4)
print(" K21y   c       ", K21y_c)
print(" oK21y   c      ", oK21y_c)

print("-----------------------------------------")

K31y_d7 =  det7(dx,0.,0.,0.,0.,0.,0.,\
                0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K31y_d4  = -dx**3*det4(a3p1,b2pta1,b3p1,b4pta1,a3p2,b2pta2,b3p2,b4pta2,\
                       a3p3,b2pta3,b3p3,b4pta3,a3p4,b2pta4,b3p4,b4pta4)

K31y_c = dx**3*kappa*(-gam1*v*(t*v+u)+ kappa*u)

oK31y_c =-dx**2*gam1*v*(t*v+u)
oK31y_s = -dx**2*gam1*u*v*(t**2+1)

print(" ")
print(" K31y   det7     ",K31y_d7)
print(" K31y   det4     ",K31y_d4)
print(" K31y   c        ", K31y_c)
print(" oK31y   c       ", oK31y_c)
print(" oK31y   s       ", oK31y_s)

print("-----------------------------------------")

K41y_d7 =  det7(dx,0.,0.,0.,0.,0.,0.,\
                0.,dx,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
          a1p1,a2p1,a3p1,a4p1,b2p1,b3p1,b4p1,\
          a1p2,a2p2,a3p2,a4p2,b2p2,b3p2,b4p2,\
          a1p3,a2p3,a3p3,a4p3,b2p3,b3p3,b4p3,\
          a1p4,a2p4,a3p4,a4p4,b2p4,b3p4,b4p4)  
    
K41y_d4 = dx**3*det4(a4p1,b2pta1,b3pta1,b4p1,a4p2,b2pta2,b3pta2,b4p2,\
                     a4p3,b2pta3,b3pta3,b4p3,a4p4,b2pta4,b3pta4,b4p4)

K41y_c = -dx**3*gam1*kappa*(t*v + u)

oK41y_c = -dx**2*gam1*(t*v + u)
oK41y_s = -dx**2*gam1*u*(t**2 + 1)


print(" ")
print(" K41y    det7    ",K41y_d7)
print(" K41y    det4    ",K41y_d4)
print(" K41y   c        ",K41y_c)
print(" oK41y   c       ",oK41y_c)
print(" oK41y   s       ",oK41y_s)

print("-----------------------------------------")


#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


print(" ")
print("***************************************************************")
print("-- determinants  differential form for bounded dprhou/dpy   -- ")
print("****************************************************************")
    
K12y_d7 =  det7(0.,dx,0.,0.,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)   
    
K12y_d4 = -dx**3*det4(a1p1, b1p1,b3pta1,b4pta1,a1p2,  b1p2,b3pta2,b4pta2,\
                     a1p3,b1p3,b3pta3,b4pta3,  a1p4,  b1p4,b3pta4,b4pta4)
        
K12y_c=dx**3*gam1*Ec*kappa*( H*gam1 - Ec*(gam+1))

oK12y_c=dx**2*gam1*Ec*( H*gam1 - Ec*(gam+1))

print(" ")
print(" K12y det7       ",K12y_d7)
print(" K12y det4       ",K12y_d4)
print(" K12y   c        ",K12y_c)
print(" oK12y   c       ",oK12y_c)

print("-----------------------------------------")

    
K22y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)    

K22y_d4 = dx**3*det4(a2p1,  b1pta1,b3pta1,b4pta1, a2p2,  b1pta2,b3pta2,b4pta2,\
                     a2p3, b1pta3,b3pta3,b4pta3, a2p4, b1pta4,b3pta4,b4pta4)

K22y_c = dx**3*kappa*(Ec*gam1**2*u - Ec*gam1*kappa*t - Ec*gam1*u + H*gam1**2*u - H*gam1*kappa*t -\
                      H*gam1*u - gam1**2*u*2*Ec + gam1*kappa**2*u + gam1*kappa*t*v**2 + gam1*kappa*u*v + kappa**2*u - kappa*u*v)


K22y_s = dx**3*kappa*(t**2*u**3 + gam1*t*Ec*kappa - gam1*u*Ec + 2*u*v**2 - 3*t*u**2*v-gam1**2*u*Ec+ H*gam1*((gam-2)*u-t*kappa) )

K22y_s2= dx**3*kappa*(Ec*gam1*(t*kappa -gam*u) +t**2*u**3  + 2*u*v**2 - 3*t*u**2*v + H*gam1*((gam-2)*u-t*kappa) )

oK22y_s = dx**2*(-Ec*gam1*gam*u +t**2*u**3  + 2*u*v**2 - 3*t*u**2*v + H*gam1*(gam-2)*u )
oK22y_s1  = dx**2 * gam1 * u *(-Ec*gam + H*(gam-2))

print(" K22y   det7     ",K22y_d7)
print(" K22y   det4     ",K22y_d4)
print(" K22y   c        ", K22y_c)
print(" K22y   s        ", K22y_s)
print(" K22y   s2       ", K22y_s2)
print(" oK22y   s       ", oK22y_s)
print(" oK22y   s1      ", oK22y_s1)
print("------------------------------------------")

K32y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,0.,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)   

K32y_d4 = -dx**3*det4(a3p1,  b1pta1,b3p1,b4pta1,  a3p2,  b1pta2,b3p2,b4pta2,\
                        a3p3, b1pta3,b3p3,b4pta3,  a3p4, b1pta4,b3p4,b4pta4)

K32y_c = dx**3*kappa*(-Ec*gam1**2*v  + Ec*gam1*v - H*gam1**2*v + H*gam1*kappa + H*gam1*v + gam1**2*v*2*Ec- gam1*kappa*Ec- kappa*u**2)

K32y_s = dx**3*kappa*(-u**2*kappa + gam1*((gam+1)*v-t*u)*Ec + H*gam1*(t*u - gam1*v))

oK32y_s = dx**2*(gam1*((gam+1)*v-t*u)*Ec + H*gam1*(t*u - gam1*v))
oK32y_s1 = dx**2*gam1*u*t*( gam*Ec + H*(2 - gam ))

print(" K32y   det7     ",K32y_d7)
print(" K32y   det4     ",K32y_d4)
print(" K32y   c        ",K32y_c)
print(" K32y   s        ",K32y_s)
print(" oK32y   s       ",oK32y_s)
print(" oK32y   s1      ",oK32y_s1)
print("----------------------------------------")

K42y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,0.,0.,\
                0.,0.,dx,0.,0.,dy,0.,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b3p1,b4p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b3p2,b4p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b3p3,b4p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b3p4,b4p4)   
          
K42y_d4 = dx**3*det4(a4p1,  b1pta1,b3pta1,b4p1,  a4p2,  b1pta2,b3pta2,b4p2,\
                     a4p3, b1pta3,b3pta3,b4p3,  a4p4, b1pta4,b3pta4,b4p4)
    

K42y_c=(dx**3*gam1*kappa*( -H*gam1+Ec*(gam+1)))

oK42y_c=dx**2*gam1*( -H*gam1+Ec*(gam+1))

print(" K42y   det7     ",K42y_d7)
print(" K42y   det4     ",K42y_d4)
print(" K42y   c        ", K42y_c)
print(" oK42y   c       ", oK42y_c)


print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded dprhov/dpy   --- ")
print("****************************************************************")

K13y_d7 =  det7(0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)   
    
K13y_d4 = -dx**3*det4(a1p1, b1p1,b2pta1,b4pta1,a1p2,  b1p2,b2pta2,b4pta2,\
                      a1p3,b1p3,b2pta3,b4pta3,  a1p4,  b1p4,b2pta4,b4pta4)

K13y_c =  dx**3*gam1*Ec*kappa*t*(-H*gam1 + Ec*(gam+1))

oK13y_c =  dx**2*gam1*Ec*t*(-H*gam1 + Ec*(gam+1))

print(" ")
print(" K13y    det7     ",K13y_d7)
print(" K13y    det4     ",K13y_d4)
print(" K13y   c         ", K13y_c)
print(" oK13y   c        ", oK13y_c)

print("-----------------------------------------")
    
K23y_d7   =  det7(dx,0.,0.,0.,dy,0.,0.,\
                  0.,0.,dx,0.,0.,0.,0.,\
                  0.,0.,0.,dx,0.,0.,dy,\
                  a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
                  a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
                  a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
                  a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)   
            
K23y_d4 = dx**3*det4(a2p1, b1pta1,b2p1,b4pta1,a2p2, b1pta2,b2p2,b4pta2,\
                         a2p3,b1pta3,b2p3,b4pta3,a2p4, b1pta4,b2p4,b4pta4)
    
K23y_c = dx**3*kappa*(-Ec*gam1**2*t*u + Ec*gam1*v - H*gam1**2*t*u + H*gam1*v + gam1**2*kappa*u**2 + gam1**2*t*u*v**2 + gam1**2*u**2*v + gam1*kappa*Ec*2+ kappa*v**2)

K23y_s = dx**3*kappa*( gam1*((gam+1)*t*u-v)*Ec + v**2*kappa + H*gam1*(v - gam1*t*u) )


oK23y_s = dx**2*( gam1*gam*t*u*Ec + H*gam1*(v - gam1*t*u) )
oK23y_s1 = dx**2*gam1*u*t*( gam*Ec + H*(2 - gam ))
print("----")
print(" K23y   det7      ",K23y_d7)
print(" K23y   det4      ",K23y_d4)
print(" K23y   c         ",K23y_c)
print(" K23y   s         ",K23y_s)
print(" oK23y   s        ",oK23y_s)
print(" oK23y   s1       ",oK23y_s1)
print("-----------------------------------------")
    
K33y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)    
 
K33y_d4 =  -dx**3*det4( a3p1, b1pta1, b2pta1,b4pta1, a3p2,  b1pta2, b2pta2,b4pta2,\
                         a3p3,b1pta3, b2pta3,b4pta3, a3p4, b1pta4, b2pta4,b4pta4)     
    
K33y_c = dx**3*kappa*t*(Ec*gam1**2*v  - Ec*gam1*v + H*gam1**2*v - H*gam1*kappa - H*gam1*v - gam1**2*v*2*Ec + gam1*kappa*Ec + kappa*u**2)

K33y_s = dx**3*kappa*t*(H*gam1*(gam1*v-t*u) - 2*gam1*v*Ec - gam1**2*v*Ec + u**2*kappa + gam1*t*u*Ec)

oK33y_s = dx**2*t*(H*gam1*(gam1*v-t*u) - 2*gam1*v*Ec - gam1**2*v*Ec + gam1*t*u*Ec)
oK33y_s1 = dx**2 *gam1*u *t**2 *(H*(gam-2) -Ec*gam)

print("----")
print(" K33y    det7     ",K33y_d7)
print(" K33y    det4     ",K33y_d4)
print(" K33y   c         ",K33y_c)
print(" K33y   s         ",K33y_s)
print(" oK33y   s        ",oK33y_s)
print(" oK33y   s1       ",oK33y_s1)
print("-----------------------------------------")

K43y_d7 = det7(dx,0.,0.,0.,dy,0.,0.,\
               0.,dx,0.,0.,0.,dy,0.,\
               0.,0.,dx,0.,0.,0.,0.,\
            a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b4p1,\
            a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b4p2,\
            a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b4p3,\
            a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b4p4)    
    
K43y_d4 = dx**3*det4(a4p1,  b1pta1,b2pta1,b4p1,  a4p2,  b1pta2,b2pta2,b4p2,\
                      a4p3, b1pta3,b2pta3,b4p3,  a4p4, b1pta4,b2pta4,b4p4)

K43y_c =  (dx**3*gam1*kappa*t*(H*gam1 - (gam+1)*Ec))

oK43y_c =  dx**2*gam1*t*(H*gam1 - (gam+1)*Ec)

print("----")
print(" K43y   det7       ",K43y_d7)
print(" K43y   det4       ",K43y_d4)
print(" K43y   c          ",K43y_c)
print(" oK43y   c         ",oK43y_c)
print("-----------------------------------------")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

print(" ")
print("***************************************************************")
print("-- determinants differential form for bounded drhoE/dpy   --- ")
print("****************************************************************")

K14y_d7 =  det7(0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                0.,0.,0.,dx,0.,0.,0.,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)   
    
K14y_d4 = -dx**3*det4(a1p1,b1p1,b2pta1,b3pta1,a1p2,  b1p2,b2pta2,b3pta2,\
                      a1p3,b1p3,b2pta3,b3pta3,  a1p4,  b1p4,b2pta4,b3pta4)

K14y_c= -Ec* dx**3 *gam1 * kappa * (u+t*v)*(gam1*Ec+H*(2-gam))

oK14y_c= -dx**2 *gam1 *Ec* (u+t*v)*(gam1*Ec+H*(2-gam))
oK14y_s = -dx**2*gam1*Ec*u*(1+t**2)*(gam1*Ec + H*(2-gam))

print(" ")
print(" K14y  det7       ",K14y_d7)
print(" K14y  det4       ",K14y_d4)
print(" K14y   c         ",K14y_c)
print(" oK14y   c        ",oK14y_c)
print(" oK14y   s        ",oK14y_s)

print("-----------------------------------------")

K24y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
                0.,0.,0.,dx,0.,0.,0.,\
                a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
                a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
                a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
                a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)  
    
K24y_d4 =  dx**3*det4(a2p1, b1pta1,b2p1,b3pta1,a2p2,  b1pta2,b2p2,b3pta2,\
                      a2p3,b1pta3,b2p3,b3pta3,a2p4, b1pta4,b2p4,b3pta4)
        
K24y_c= -dx**3 * kappa*(2*Ec*gam1 + gam*kappa*v)*(gam1*Ec + H*(2-gam))

oK24y_c= -dx**2* 2*Ec*gam1*(gam1*Ec + H*(2-gam))
oK24y_s = -dx**2 *u**2 * (1+t**2)*gam1*(gam1*Ec + H*(2-gam))
print("----")
print(" K24y   det7      ",K24y_d7)
print(" K24y   det4      ",K24y_d4)
print(" K24y   c         ",K24y_c)
print(" oK24y   c        ",oK24y_c)
print(" oK24y   s        ",oK24y_s)

print("-----------------------------------------")

K34y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,0.,dx,0.,0.,0.,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)  
                 
K34y_d4 = -dx**3*det4(a3p1, b1pta1,b2pta1,b3p1,a3p2,  b1pta2,b2pta2,b3p2,\
                     a3p3,b1pta3,b2pta3,b3p3,a3p4, b1pta4,b2pta4,b3p4)    
    
K34y_c= dx**3*kappa*(-Ec*gam1**2*t*v**2 - Ec*gam1**2*u*v + Ec*gam1*kappa*u - H*gam1**2*t*v**2 -\
                     H*gam1**2*u*v + H*gam1*kappa*u + H*gam1*t*v**2 + H*gam1*u*v - H*kappa*u +\
                         gam1**2*kappa*u*v**2 + 1.0*gam1**2*t*v**4 + 1.0*gam1**2*u**3*v + 2.0*gam1**2*u*v**3 - 1.0*gam1*kappa*u**3 - 1.0*gam1*kappa*u*v**2)

K34y_s = dx**3*kappa*(-u*kappa + gam1*t*v**2 + gam1*u*v)*(gam1*Ec +H*(2-gam))

oK34y_s = dx**2* gam1*(t*v**2 + u*v)*(gam1*Ec +H*(2-gam))
oK34y_s1 = dx**2*gam1*v*u*(t**2+1)*(gam1*Ec + H*(2-gam))
print("----")
print(" K34y    det7      ",K34y_d7)
print(" K34y    det4      ",K34y_d4)
print(" K23y    c         ",K34y_c)
print(" K34y    s         ",K34y_s)
print(" oK34y    s        ",oK34y_s)
print(" oK34y    s1       ",oK34y_s1)
print("-----------------------------------------")

K44y_d7 =  det7(dx,0.,0.,0.,dy,0.,0.,\
                0.,dx,0.,0.,0.,dy,0.,\
                0.,0.,dx,0.,0.,0.,dy,\
             a1p1,a2p1,a3p1,a4p1,b1p1,b2p1,b3p1,\
             a1p2,a2p2,a3p2,a4p2,b1p2,b2p2,b3p2,\
             a1p3,a2p3,a3p3,a4p3,b1p3,b2p3,b3p3,\
             a1p4,a2p4,a3p4,a4p4,b1p4,b2p4,b3p4)  
    
K44y_d4 = dx**3*det4(a4p1,   b1pta1,b2pta1,b3pta1,a4p2,   b1pta2,b2pta2,b3pta2,\
                      a4p3,  b1pta3,b2pta3,b3pta3,a4p4,  b1pta4,b2pta4,b3pta4)
    
K44y_c =  dx**3*kappa*(-Ec*gam1**2*t*v - Ec*gam1**2*u - Ec*gam1*kappa*t-Ec*gam1*t*v -Ec*gam1*u-H*gam1**2*t*v - \
                       H*gam1**2*u -H*gam1*kappa*t +gam1**2*kappa*u*v + gam1**2*t*v**3 +gam1**2*u**3 + 2.0*gam1**2*u*v**2 +gam1*kappa**2*u +gam1*kappa*t*v**2 + 2.0*gam1*kappa*u*v + gam1*t*v**3 +gam1*u**3 + 2.0*gam1*u*v**2 + kappa**2*u)

 
K44y_s = dx**3 * kappa * (u*kappa**2 + gam*gam1*u*Ec + gam1*t**2*u*Ec + gam1**2*t*v*Ec -H*gam1**2*u - H*gam1**2*t*v - H*gam1*t**2*u +H*gam1*t*v )

oK44y_s = dx**2* (gam*gam1*u*Ec + gam1*t**2*u*Ec + gam1**2*t*v*Ec -H*gam1**2*u - H*gam1**2*t*v )


oK44y_s = dx**2* gam1*(gam*u*Ec*(1.+t**2) -H*gam1*u*(1.+t**2))

oK44y_s1 = dx**2* gam1*(1.+t**2)*u*(gam*Ec -H*gam1)

print(" ")
print(" K44y_d7    det7    ",K44y_d7)
print(" K44y_d7    det4    ",K44y_d4)
print(" K44y   c           ",K44y_c)
print(" K44y   s           ",K44y_s)
print(" oK44y   s          ",oK44y_s)
print(" oK44y   s1         ",oK44y_s1)
print("-----------------------------------------")

#########################################################################

print("  ")
print(" **************************************************************** ")
print("    ratio of corresponding oKx oKy coefficients  ")
print(" **************************************************************** ")
print("  -t=-dy/dx       = ",(-dy/dx))
print(" -------- -  -------   -----   --------  ")
print(" oK11x/oK11y  det7     ",oK11x_c/oK11y_s)
print(" oK21x/oK21y  det7     ",oK21x_c/oK21y_c)
print(" oK31x/oK31y  det7     ",oK31x_s/oK31y_c)
print(" oK41x/oK41y  det7     ",oK41x_c/oK41y_c)
print(" -------- -  -------   -----   --------  ")
print(" oK12x/oK12y  det7     ",oK12x_s/oK12y_c)
print(" oK22x/oK22y  det7     ",oK22x_s/oK22y_s)
print(" oK32x/oK32y  det7     ",oK32x_s/oK32y_s)
print(" oK42x/oK42y  det7     ",oK42x_c/oK42y_c)
print(" -------- -  -------   -----   --------  ")
print(" oK13x/oK13y  det7     ",oK13x_s/oK13y_c)
print(" oK23x/oK23y  det7     ",oK23x_s /oK23y_s)
print(" oK33x/oK33y  det7     ",oK33x_s/oK33y_s)
print(" oK43x/oK43y  det7     ",oK43x_c/oK43y_c)
print(" -------- -  -------   -----   --------  ")
print(" oK14x/oK14y  det7     ",oK14x_c/oK14y_c)
print(" oK24x/oK24y  det7     ",oK24x_c/oK24y_c)
print(" oK34x/oK34y  det7     ",oK34x_s/oK34y_s)
print(" oK44x/oK44y  det7     ",oK44x_s/oK44y_s)
print(" -------- -  -------   -----   --------  ")


#########################################################################
print(" ")
print("**********************************************************")
print(" print null differential forms ")
print("**********************************************************")
print("          --------------------")
print(" ",round(oK11x_c,3)," drho -",round(oK21x_c,3)," drhou +",round(oK31x_s,3)," drhov -",round(oK41x_c,3)," drhoE = 0")
print(" ",round(oK12x_s,3)," drho -",round(oK22x_s,3)," drhou +",round(oK32x_s,3)," drhov -",round(oK42x_c,3)," drhoE = 0")
print(" ",round(oK13x_s,3)," drho -",round(oK23x_s,3)," drhou +",round(oK33x_s,3)," drhov -",round(oK43x_c,3)," drhoE = 0")
print(" ",round(oK14x_c,3)," drho -",round(oK24x_c,3)," drhou +",round(oK34x_s,3)," drhov -",round(oK44x_s,3)," drhoE = 0")

print(" ",round(oK11y_s,3)," drho -",round(oK21y_c,3)," drhou +",round(oK31y_c,3)," drhov -",round(oK41y_c,3)," drhoE = 0")
print(" ",round(oK12y_c,3)," drho -",round(oK22y_s,3)," drhou +",round(oK32y_s,3)," drhov -",round(oK42y_c,3)," drhoE = 0")
print(" ",round(oK13y_c,3)," drho -",round(oK23y_s,3)," drhou +",round(oK33y_s,3)," drhov -",round(oK43y_c,3)," drhoE = 0")
print(" ",round(oK14y_c,3)," drho -",round(oK24y_c,3)," drhou +",round(oK34y_s,3)," drhov -",round(oK44y_s,3)," drhoE = 0")


print("   ")
print(" print scaled null differential forms  ")
print(" -------------------------------------------")
print(" ",round(oK11x_c,3)," drho -",round(oK21x_c,3)," drhou +",round(oK31x_s,3)," drhov -",round(oK41x_c,3)," drhoE = 0")
c = oK11x_c/oK12x_s
print(" ",round(oK12x_s*c,3)," drho -",round(oK22x_s*c,3)," drhou +",round(oK32x_s*c,3)," drhov -",round(oK42x_c*c,3)," drhoE = 0")
c = oK11x_c/oK13x_s
print(" ",round(oK13x_s*c,3)," drho -",round(oK23x_s*c,3)," drhou +",round(oK33x_s*c,3)," drhov -",round(oK43x_c*c,3)," drhoE = 0")
c = oK11x_c/oK14x_c
print(" ",round(oK14x_c*c,3)," drho -",round(oK24x_c*c,3)," drhou +",round(oK34x_s*c,3)," drhov -",round(oK44x_s*c,3)," drhoE = 0")


c = oK11x_c/oK11y_s
print(" ",round(oK11y_s*c,3)," drho -",round(oK21y_c*c,3)," drhou +",round(oK31y_c*c,3)," drhov -",round(oK41y_c*c,3)," drhoE = 0")
c = oK11x_c/oK12y_c
print(" ",round(oK12y_c*c,3)," drho -",round(oK22y_s*c,3)," drhou +",round(oK32y_s*c,3)," drhov -",round(oK42y_c*c,3)," drhoE = 0")
c = oK11x_c/oK13y_c
print(" ",round(oK13y_c*c,3)," drho -",round(oK23y_s*c,3)," drhou +",round(oK33y_s*c,3)," drhov -",round(oK43y_c*c,3)," drhoE = 0")
c = oK11x_c/oK14y_c
print(" ",round(oK14y_c*c,3)," drho -",round(oK24y_c*c,3)," drhou +",round(oK34y_s*c,3)," drhov -",round(oK44y_s*c,3)," drhoE = 0")
print("     ")

print("====================================================================================")
print(" proportionality of differential forms for the existence  ")
print(" of rho derivatives in x directions with ")
print(" (2Ec-H) drho -u drhou -v drhov +drhoE = 0 ")
print("========================================================")
#
print(" ")
print(" ",round(oK11x_c,4)," drho -",round(oK21x_c,4)," drhou +",round(oK31x_s,4)," drhov -",round(oK41x_c,4)," drhoE = 0")

c = oK11x_c/(2*Ec-H)
print(" ")
print(" scaled. Scaling coeff ",c)
print(" ")
print(" ",round(oK11x_c,4)," drho +",round(-u*c,4)," drhou +",round(-v*c,4)," drhov +",round(c,4)," drhoE = 0")
print(" ")

print(" ================================================================================")
print(" proportionality of differential forms for the existence ")
print(" of rhoE derivatives in x and y directions with  (( G = gam1*Ec+H*(2-gam) )) ")
print( " -Ec G drho +uG drhou +vG drhov + (H gam1-gam*Ec) drhoE = 0 ")
print(" =====================================================================")
#
print("   ")
print(" ",round(oK14y_c,4)," drho -",round(oK24y_c,4)," drhou +",round(oK34y_s,4)," drhov -",round(oK44y_s,4)," drhoE = 0")
G = gam1*Ec+H*(2-gam)
c = oK14y_c/(-Ec*G) 
print(" ")
print(" scaled. Scaling coeff ",c)
print(" ")
print(" ",round(oK14y_c,4)," drho +",round(u*G*c,4)," drhou +",round(v*G*c,4)," drhov +",round((H*gam1-gam*Ec)*c,4)," drhoE = 0")
print(" ")



print(" ========================================================================")
print(" numerical investigation of the rank from (2x2) and (3x3) minors  ")
print(" ========================================================================")
print("   ")
print(" ------------------------------------------------------------------------")
print("Minor of rank 2 for the differential form (using  x derivatives coeff) ")
print(" ------------------------------------------------------------------------")
print(det2(oK11x_c, oK21x_c, oK12x_s, oK22x_s) )
print(det2(oK31x_s, oK41x_c, oK32x_s, oK42x_c))
print(det2(oK13x_s, oK23x_s, oK14x_c, oK24x_c))
print(det2(oK33x_s, oK43x_c, oK34x_s, oK44x_s))

print("   ")
print(" ------------------------------------------------------------------------")
print("Minor of rank 2 for the differential form (using y derivatives coeff)")
print(" ------------------------------------------------------------------------")
print(det2(oK11y_s, oK21y_c, oK12y_c, oK22y_s))
print(det2(oK31y_c, oK41y_c, oK32y_s, oK42y_c))
print(det2(oK13y_c, oK23y_s, oK14y_c, oK24y_c))
print(det2(oK33y_s, oK43y_c, oK34y_s, oK44y_s))

print("   ")
print(" -------------------------------------------------------------------")
print("Minor of rank 3 for the differential (using x derivatives coeff) ")
print(" ---------------------------------------------------------------------")
print("123.123 ",det3(oK11x_c , oK21x_c, oK31x_s, oK12x_s , oK22x_s, oK32x_s, oK13x_s, oK23x_s, oK33x_s))
print("123.234 ",det3(oK12x_s , oK22x_s, oK32x_s, oK13x_s, oK23x_s, oK33x_s, oK14x_c, oK24x_c, oK34x_s))
print("123.124 ",det3(oK11x_c , oK21x_c, oK31x_s, oK12x_s , oK22x_s, oK32x_s, oK14x_c, oK24x_c, oK34x_s))
print("123.134 ",det3(oK11x_c , oK21x_c, oK31x_s, oK13x_s , oK23x_s, oK33x_s, oK14x_c, oK24x_c, oK34x_s))
print("234.123 ",det3(oK21x_c,oK31x_s,oK41x_c, oK22x_s,oK32x_s,oK42x_c , oK23x_s,oK33x_s,oK43x_c ))
print("234.124 ",det3(oK21x_c,oK31x_s,oK41x_c, oK22x_s,oK32x_s,oK42x_c , oK24x_c,oK34x_s,oK44x_s ))
print("234.134 ",det3(oK21x_s,oK31x_s,oK41x_c, oK23x_s,oK33x_s,oK43x_c, oK24x_c,oK34x_s,oK44x_s))
print("234.234 ",det3(oK22x_s,oK32x_s,oK42x_c, oK23x_s,oK33x_s,oK43x_c, oK24x_c,oK34x_s,oK44x_s))
print("134.123 ",det3(oK11x_c , oK31x_s, oK41x_c, oK12x_s , oK32x_s, oK42x_c, oK13x_s, oK33x_s, oK43x_c))
print("134.124 ",det3(oK11x_c , oK31x_s, oK41x_c, oK12x_s , oK32x_s, oK42x_c, oK14x_c, oK34x_s, oK44x_s))
print("134.134 ",det3(oK11x_c , oK31x_s, oK41x_c, oK13x_s , oK33x_s, oK43x_c, oK14x_c, oK34x_s, oK44x_s))
print("134.234 ",det3(oK12x_s , oK32x_s, oK42x_c, oK13x_s , oK33x_s, oK43x_c, oK14x_c, oK34x_s, oK44x_s))

